$title The Farmer's Problem formulated for GAMS/DECIS (FARM,SEQ=199)

$ontext

This model helps a farmer to decide how to allocate
his or her land. The yields are uncertain.


Birge, R, and Louveaux, F V, Introduction to Stochastic Programming.
Springer, 1997.

$offtext

$if not set decisalg $set decisalg decism

set crop / wheat, corn, sugarbeets /;
set cropr(crop) crops required for feeding cattle /wheat, corn/;
set cropx /wheat,
           corn,
           beets1 up to 6000 ton,
           beets2 in excess of 6000 ton/;

parameter yield(crop) tons per acre /
          wheat        2.5
          corn         3
          sugarbeets  20
/;

parameter plantcost(crop) dollars per acre /
          wheat        150
          corn         230
          sugarbeets   260
/;

parameter sellprice(cropx)  dollars per ton /
          wheat        170
          corn         150
          beets1        36
          beets2        10
/;

parameter purchprice(cropr) dollars per ton /
          wheat        238
          corn         210
/;

parameter minreq(cropr) minimum requirements in ton /
          wheat        200
          corn         240
/;

scalar land available land /500/;
scalar maxbeets1 max allowed /6000/;

*--------------------------------------------------------------------------
* First a non-stochastic version
*--------------------------------------------------------------------------
variables
  x(crop)  acres of land
  w(cropx) crops sold
  y(cropr) crops purchased
  yld(crop) yield
  profit   objective variable
;
positive variables x,w,y;

equations
  profitdef  objective function
  landuse    capacity
  req(cropr) crop requirements for cattle feed
  ylddef     calc yields
  beets      total beet production
;

$ontext
  The YLD variable and YLDDEF equation isolate the stochastic
  YIELD parameter into one equation, making the DECIS setup
  somewhat easier than if we would substitute YLD out of
  the model.
$offtext

profitdef.. profit =e= -sum(crop, plantcost(crop)*x(crop)) - sum(cropr, purchprice(cropr)*y(cropr))
                   + sum(cropx, sellprice(cropx)*w(cropx));

landuse.. sum(crop, x(crop)) =l= land;

ylddef(crop).. yld(crop) =e= yield(crop)*x(crop);

req(cropr).. yld(cropr) + y(cropr) - sum(sameas(cropx,cropr),w(cropx)) =g= minreq(cropr);

beets.. w('beets1')+w('beets2') =l= yld('sugarbeets');
w.up('beets1') = maxbeets1;


option lp=cplex;

model simple /profitdef,landuse,req,beets,ylddef/;
solve simple using lp maximizing profit;

display x.l, y.l, w.l;